#[non_exhaustive]#[repr(u8)]pub enum CompressionType {
None = 0,
Gzip = 1,
Snappy = 2,
Lz4 = 3,
Zstd = 4,
}Expand description
Codec identifier matching the lowest three bits of Kafka’s record-batch attribute byte.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl CompressionType
impl CompressionType
Sourcepub fn from_attribute_bits(b: u8) -> Option<Self>
pub fn from_attribute_bits(b: u8) -> Option<Self>
Decode the lowest three bits of a Kafka record-batch attribute byte.
Returns None for codec ids outside 0..=4.
Sourcepub fn as_attribute_bits(self) -> u8
pub fn as_attribute_bits(self) -> u8
Encode this codec into the lowest three bits of an attribute byte.